import * as types from './graphql';
import { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core';
/**
 * Map of all GraphQL operations in the project.
 *
 * This map has several performance disadvantages:
 * 1. It is not tree-shakeable, so it will include all operations in the project.
 * 2. It is not minifiable, so the string of a GraphQL query will be multiple times inside the bundle.
 * 3. It does not support dead code elimination, so it will add unused operations.
 *
 * Therefore it is highly recommended to use the babel or swc plugin for production.
 */
declare const documents: {
    "query FetchMapItem($universeId: Int!, $userId: Int!) {\n  rooadmap_gis_map_item(\n    where: {_and: [{info: {map: {universe_id: {_eq: $universeId}}}}, {info: {states: {_and: {user_id: {_eq: $userId}, visibility: {_eq: true}}}}}]}\n  ) {\n    id\n    info {\n      id\n    }\n  }\n}\n\nquery GetAllPieceTypes {\n  piece_type {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetAtomicPieceTypes {\n  piece_type(where: {is_atomic: {_eq: true}}) {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetTargetViewTypes {\n  target_view_type {\n    builder_version\n    id\n    renderer_version\n    builder_name\n    name\n    renderer_name\n  }\n}": DocumentNode<types.FetchMapItemQuery, types.Exact<{
        universeId: number;
        userId: number;
    }>>;
};
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 *
 *
 * @example
 * ```ts
 * const query = graphql(`query GetUser($id: ID!) { user(id: $id) { name } }`);
 * ```
 *
 * The query argument is unknown!
 * Please regenerate the types.
 */
export declare function graphql(source: string): unknown;
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export declare function graphql(source: "query FetchMapItem($universeId: Int!, $userId: Int!) {\n  rooadmap_gis_map_item(\n    where: {_and: [{info: {map: {universe_id: {_eq: $universeId}}}}, {info: {states: {_and: {user_id: {_eq: $userId}, visibility: {_eq: true}}}}}]}\n  ) {\n    id\n    info {\n      id\n    }\n  }\n}\n\nquery GetAllPieceTypes {\n  piece_type {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetAtomicPieceTypes {\n  piece_type(where: {is_atomic: {_eq: true}}) {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetTargetViewTypes {\n  target_view_type {\n    builder_version\n    id\n    renderer_version\n    builder_name\n    name\n    renderer_name\n  }\n}"): (typeof documents)["query FetchMapItem($universeId: Int!, $userId: Int!) {\n  rooadmap_gis_map_item(\n    where: {_and: [{info: {map: {universe_id: {_eq: $universeId}}}}, {info: {states: {_and: {user_id: {_eq: $userId}, visibility: {_eq: true}}}}}]}\n  ) {\n    id\n    info {\n      id\n    }\n  }\n}\n\nquery GetAllPieceTypes {\n  piece_type {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetAtomicPieceTypes {\n  piece_type(where: {is_atomic: {_eq: true}}) {\n    id\n    piece_type_title\n    is_inmap\n    is_outmap\n    is_set_on_locus_design\n    title\n    description\n    is_judge_piece\n    target_view_type_id\n    is_atomic\n  }\n}\n\nquery GetTargetViewTypes {\n  target_view_type {\n    builder_version\n    id\n    renderer_version\n    builder_name\n    name\n    renderer_name\n  }\n}"];
export type DocumentType<TDocumentNode extends DocumentNode<any, any>> = TDocumentNode extends DocumentNode<infer TType, any> ? TType : never;
export {};
